function [W,i,gap] = CUR_prox(W0,L,lambda_row,lambda_col,maxIter,epsilon)

W = W0;
Xi_row = zeros(size(W));
Xi_col = zeros(size(W));
f_primal0 = (1/2)*norm(W-W0,'fro')^2 + (lambda_row/L)*sum(sqrt(sum(W'.^2))) + (lambda_col/L)*sum(sqrt(sum(W.^2)));
for i = 1:maxIter
	% Prox with respect to columns
	W_old = W;
	W = softThreshold_col(W-Xi_col,L,lambda_col);
	Xi_col = W - (W_old - Xi_col);
	
	% Prox with respect to rows
	W_old = W;
	W = softThreshold_row(W-Xi_row,L,lambda_row);
	Xi_row = W - (W_old - Xi_row);
	
	% Compute duality gap
	f_primal = (1/2)*norm(W-W0,'fro')^2 + (lambda_row/L)*sum(sqrt(sum(W'.^2))) + (lambda_col/L)*sum(sqrt(sum(W.^2)));
	f_dual = (1/2)*norm(W0,'fro')^2 - (1/2)*norm(W0 + Xi_row + Xi_col,'fro')^2;
	gap = f_primal - f_dual;
	if f_primal <= f_primal0 && gap < epsilon
		break;
	end
end
end

%% Prox solvers with respect to blocks
function [W] = softThreshold_row(W,L,lambda)
nRows = size(W,1);
for r = 1:nRows
	nrm = norm(W(r,:));
	if nrm > 0
		W(r,:) = (W(r,:)/nrm)*max(0,nrm-lambda/L);
	end
end
end

function [W] = softThreshold_col(W,L,lambda)
nCols = size(W,2);
for c = 1:nCols
	nrm = norm(W(:,c));
	if nrm > 0
		W(:,c) = (W(:,c)/nrm)*max(0,nrm-lambda/L);
	end
end
end